about summary refs log tree commit diff
path: root/sysdeps/libm-ieee754
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/libm-ieee754')
-rw-r--r--sysdeps/libm-ieee754/k_standard.c14
-rw-r--r--sysdeps/libm-ieee754/w_gammaf.c68
-rw-r--r--sysdeps/libm-ieee754/w_gammal.c71
-rw-r--r--sysdeps/libm-ieee754/w_lgamma.c4
-rw-r--r--sysdeps/libm-ieee754/w_lgammaf.c2
-rw-r--r--sysdeps/libm-ieee754/w_lgammal.c2
-rw-r--r--sysdeps/libm-ieee754/w_tgamma.c (renamed from sysdeps/libm-ieee754/w_gamma.c)50
-rw-r--r--sysdeps/libm-ieee754/w_tgammaf.c50
-rw-r--r--sysdeps/libm-ieee754/w_tgammal.c53
9 files changed, 134 insertions, 180 deletions
diff --git a/sysdeps/libm-ieee754/k_standard.c b/sysdeps/libm-ieee754/k_standard.c
index 82cfbe467a..42ecca9980 100644
--- a/sysdeps/libm-ieee754/k_standard.c
+++ b/sysdeps/libm-ieee754/k_standard.c
@@ -77,8 +77,8 @@ static double zero = 0.0;	/* used as const */
  *	37-- y1(x>X_TLOSS)
  *	38-- jn(|x|>X_TLOSS, n)
  *	39-- yn(x>X_TLOSS, n)
- *	40-- gamma(finite) overflow
- *	41-- gamma(-integer)
+ *	40-- tgamma(finite) overflow
+ *	41-- tgamma(-integer)
  *	42-- pow(NaN,0.0)
  *	43-- +0**neg
  *	44-- exp2 overflow
@@ -829,8 +829,8 @@ static double zero = 0.0;	/* used as const */
 	    case 240:
 		/* gamma(finite) overflow */
 		exc.type = OVERFLOW;
-		exc.name = type < 100 ? "gamma" : (type < 200
-						   ? "gammaf" : "gammal");
+		exc.name = type < 100 ? "tgamma" : (type < 200
+						   ? "tgammaf" : "tgammal");
 		exc.retval = HUGE_VAL;
                 if (_LIB_VERSION == _POSIX_)
 		  __set_errno (ERANGE);
@@ -843,14 +843,14 @@ static double zero = 0.0;	/* used as const */
 	    case 241:
 		/* gamma(-integer) or gamma(0) */
 		exc.type = SING;
-		exc.name = type < 100 ? "gamma" : (type < 200
-						   ? "gammaf" : "gammal");
+		exc.name = type < 100 ? "tgamma" : (type < 200
+						   ? "tgammaf" : "tgammal");
 		exc.retval = NAN;
 		if (_LIB_VERSION == _POSIX_)
 		  __set_errno (EDOM);
 		else if (!matherr(&exc)) {
 		  if (_LIB_VERSION == _SVID_) {
-			(void) WRITE2("gamma: SING error\n", 18);
+			(void) WRITE2("tgamma: SING error\n", 18);
 			exc.retval = HUGE_VAL;
 		      }
 		  __set_errno (EDOM);
diff --git a/sysdeps/libm-ieee754/w_gammaf.c b/sysdeps/libm-ieee754/w_gammaf.c
deleted file mode 100644
index bc251b3554..0000000000
--- a/sysdeps/libm-ieee754/w_gammaf.c
+++ /dev/null
@@ -1,68 +0,0 @@
-/* w_gammaf.c -- float version of w_gamma.c.
- * Conversion to float by Ian Lance Taylor, Cygnus Support, ian@cygnus.com.
- */
-
-/*
- * ====================================================
- * Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.
- *
- * Developed at SunPro, a Sun Microsystems, Inc. business.
- * Permission to use, copy, modify, and distribute this
- * software is freely granted, provided that this notice
- * is preserved.
- * ====================================================
- */
-
-#if defined(LIBM_SCCS) && !defined(lint)
-static char rcsid[] = "$NetBSD: w_gammaf.c,v 1.4 1995/11/20 22:06:48 jtc Exp $";
-#endif
-
-#include "math.h"
-#include "math_private.h"
-
-#ifdef __STDC__
-	float __gammaf(float x)
-#else
-	float __gammaf(x)
-	float x;
-#endif
-{
-        float y;
-#ifndef _IEEE_LIBM
-	if (_LIB_VERSION == _SVID_)
-	  {
-	    y = __ieee754_lgammaf_r(x,&signgam);
-
-	    if(!__finitef(y)&&__finitef(x)) {
-	      if(__floorf(x)==x&&x<=(float)0.0)
-		/* lgammaf pole */
-		return (float)__kernel_standard((double)x,(double)x,115);
-	      else
-		/* lgammaf overflow */
-		return (float)__kernel_standard((double)x,(double)x,114);
-	    }
-	  }
-	else
-	  {
-#endif
-	    int local_signgam;
-	    y = __ieee754_gammaf_r(x,&local_signgam);
-	    if (local_signgam < 0) y = -y;
-#ifdef _IEEE_LIBM
-	    return y;
-#else
-	    if(_LIB_VERSION == _IEEE_) return y;
-
-	    if(!__finitef(y)&&__finitef(x)) {
-	      if(__floorf(x)==x&&x<=(float)0.0)
-		/* gammaf pole */
-		return (float)__kernel_standard((double)x,(double)x,141);
-	      else
-		/* gammaf overflow */
-		return (float)__kernel_standard((double)x,(double)x,140);
-	    }
-	  }
-	return y;
-#endif
-}
-weak_alias (__gammaf, gammaf)
diff --git a/sysdeps/libm-ieee754/w_gammal.c b/sysdeps/libm-ieee754/w_gammal.c
deleted file mode 100644
index 68328f652a..0000000000
--- a/sysdeps/libm-ieee754/w_gammal.c
+++ /dev/null
@@ -1,71 +0,0 @@
-/* w_gammal.c -- long double version of w_gamma.c.
- * Conversion to long double by Ulrich Drepper,
- * Cygnus Support, drepper@cygnus.com.
- */
-
-/*
- * ====================================================
- * Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.
- *
- * Developed at SunPro, a Sun Microsystems, Inc. business.
- * Permission to use, copy, modify, and distribute this
- * software is freely granted, provided that this notice
- * is preserved.
- * ====================================================
- */
-
-#if defined(LIBM_SCCS) && !defined(lint)
-static char rcsid[] = "$NetBSD: $";
-#endif
-
-/* long double gammal(double x)
- * Return the Gamma function of x.
- */
-
-#include "math.h"
-#include "math_private.h"
-
-#ifdef __STDC__
-	long double __gammal(long double x)
-#else
-	long double __gammal(x)
-	long double x;
-#endif
-{
-        long double y;
-#ifndef _IEEE_LIBM
-	if (_LIB_VERSION == _SVID_)
-	  {
-	    y = __ieee754_lgammal_r(x,&signgam);
-
-	    if(!__finitel(y)&&__finitel(x)) {
-	      if(__floorl(x)==x&&x<=(long double)0.0)
-		/* lgamma pole */
-		return (long double)__kernel_standard((double)x,(double)x,15);
-	      else
-		/* lgamma overflow */
-		return (long double)__kernel_standard((double)x,(double)x,14);
-	    }
-	  }
-	else
-	  {
-#endif
-	    int local_signgam;
-	    y = __ieee754_gammal_r(x,&local_signgam);
-	    if (local_signgam < 0) y = -y;
-#ifdef _IEEE_LIBM
-	    return y;
-#else
-	    if(_LIB_VERSION == _IEEE_) return y;
-
-	    if(!__finitel(y)&&__finitel(x)) {
-	      if(__floorl(x)==x&&x<=0.0)
-                return __kernel_standard(x,x,241); /* gamma pole */
-	      else
-                return __kernel_standard(x,x,240); /* gamma overflow */
-	    }
-	  }
-	return y;
-#endif
-}
-weak_alias (__gammal, gammal)
diff --git a/sysdeps/libm-ieee754/w_lgamma.c b/sysdeps/libm-ieee754/w_lgamma.c
index bbb53f53e8..0cc62a1784 100644
--- a/sysdeps/libm-ieee754/w_lgamma.c
+++ b/sysdeps/libm-ieee754/w_lgamma.c
@@ -50,7 +50,11 @@ static char rcsid[] = "$NetBSD: w_lgamma.c,v 1.6 1995/05/10 20:49:24 jtc Exp $";
 #endif
 }
 weak_alias (__lgamma, lgamma)
+strong_alias (__lgamma, __gamma)
+weak_alias (__gamma, gamma)
 #ifdef NO_LONG_DOUBLE
 strong_alias (__lgamma, __lgammal)
 weak_alias (__lgamma, lgammal)
+strong_alias (__gamma, __gammal)
+weak_alias (__gamma, gammal)
 #endif
diff --git a/sysdeps/libm-ieee754/w_lgammaf.c b/sysdeps/libm-ieee754/w_lgammaf.c
index 369dee6749..4c64aa4130 100644
--- a/sysdeps/libm-ieee754/w_lgammaf.c
+++ b/sysdeps/libm-ieee754/w_lgammaf.c
@@ -49,3 +49,5 @@ static char rcsid[] = "$NetBSD: w_lgammaf.c,v 1.3 1995/05/10 20:49:30 jtc Exp $"
 #endif
 }
 weak_alias (__lgammaf, lgammaf)
+strong_alias (__lgammaf, __gammaf)
+weak_alias (__gammaf, gammaf)
diff --git a/sysdeps/libm-ieee754/w_lgammal.c b/sysdeps/libm-ieee754/w_lgammal.c
index 9db2ce2693..41104e47e4 100644
--- a/sysdeps/libm-ieee754/w_lgammal.c
+++ b/sysdeps/libm-ieee754/w_lgammal.c
@@ -54,3 +54,5 @@ static char rcsid[] = "$NetBSD: $";
 #endif
 }
 weak_alias (__lgammal, lgammal)
+strong_alias (__lgammal, __gammal)
+weak_alias (__gammal, gammal)
diff --git a/sysdeps/libm-ieee754/w_tgammaf.c b/sysdeps/libm-ieee754/w_tgammaf.c
new file mode 100644
index 0000000000..152f4be156
--- /dev/null
+++ b/sysdeps/libm-ieee754/w_tgammaf.c
@@ -0,0 +1,50 @@
+/* w_gammaf.c -- float version of w_gamma.c.
+ * Conversion to float by Ian Lance Taylor, Cygnus Support, ian@cygnus.com.
+ */
+
+/*
+ * ====================================================
+ * Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.
+ *
+ * Developed at SunPro, a Sun Microsystems, Inc. business.
+ * Permission to use, copy, modify, and distribute this
+ * software is freely granted, provided that this notice
+ * is preserved.
+ * ====================================================
+ */
+
+#if defined(LIBM_SCCS) && !defined(lint)
+static char rcsid[] = "$NetBSD: w_gammaf.c,v 1.4 1995/11/20 22:06:48 jtc Exp $";
+#endif
+
+#include "math.h"
+#include "math_private.h"
+
+#ifdef __STDC__
+	float __tgammaf(float x)
+#else
+	float __tgammaf(x)
+	float x;
+#endif
+{
+        float y;
+	int local_signgam;
+	y = __ieee754_gammaf_r(x,&local_signgam);
+	if (local_signgam < 0) y = -y;
+#ifdef _IEEE_LIBM
+	return y;
+#else
+	if(_LIB_VERSION == _IEEE_) return y;
+
+	if(!__finitef(y)&&__finitef(x)) {
+	  if(__floorf(x)==x&&x<=(float)0.0)
+	    /* tgammaf pole */
+	    return (float)__kernel_standard((double)x,(double)x,141);
+	  else
+	    /* tgammaf overflow */
+	    return (float)__kernel_standard((double)x,(double)x,140);
+	}
+	return y;
+#endif
+}
+weak_alias (__tgammaf, tgammaf)
diff --git a/sysdeps/libm-ieee754/w_tgammal.c b/sysdeps/libm-ieee754/w_tgammal.c
new file mode 100644
index 0000000000..9efce2bb95
--- /dev/null
+++ b/sysdeps/libm-ieee754/w_tgammal.c
@@ -0,0 +1,53 @@
+/* w_gammal.c -- long double version of w_gamma.c.
+ * Conversion to long double by Ulrich Drepper,
+ * Cygnus Support, drepper@cygnus.com.
+ */
+
+/*
+ * ====================================================
+ * Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.
+ *
+ * Developed at SunPro, a Sun Microsystems, Inc. business.
+ * Permission to use, copy, modify, and distribute this
+ * software is freely granted, provided that this notice
+ * is preserved.
+ * ====================================================
+ */
+
+#if defined(LIBM_SCCS) && !defined(lint)
+static char rcsid[] = "$NetBSD: $";
+#endif
+
+/* long double gammal(double x)
+ * Return the Gamma function of x.
+ */
+
+#include "math.h"
+#include "math_private.h"
+
+#ifdef __STDC__
+	long double __tgammal(long double x)
+#else
+	long double __tgammal(x)
+	long double x;
+#endif
+{
+        long double y;
+	int local_signgam;
+	y = __ieee754_gammal_r(x,&local_signgam);
+	if (local_signgam < 0) y = -y;
+#ifdef _IEEE_LIBM
+	return y;
+#else
+	if(_LIB_VERSION == _IEEE_) return y;
+
+	if(!__finitel(y)&&__finitel(x)) {
+	  if(__floorl(x)==x&&x<=0.0)
+	    return __kernel_standard(x,x,241); /* tgamma pole */
+	  else
+	    return __kernel_standard(x,x,240); /* tgamma overflow */
+	}
+	return y;
+#endif
+}
+weak_alias (__tgammal, tgammal)
diff --git a/sysdeps/libm-ieee754/w_gamma.c b/sysdeps/libm-ieee754/w_tgamma.c
index 3511b67d77..2adbc2e14d 100644
--- a/sysdeps/libm-ieee754/w_gamma.c
+++ b/sysdeps/libm-ieee754/w_tgamma.c
@@ -23,50 +23,32 @@ static char rcsid[] = "$NetBSD: w_gamma.c,v 1.7 1995/11/20 22:06:43 jtc Exp $";
 #include "math_private.h"
 
 #ifdef __STDC__
-	double __gamma(double x)
+	double __tgamma(double x)
 #else
-	double __gamma(x)
+	double __tgamma(x)
 	double x;
 #endif
 {
         double y;
-#ifndef _IEEE_LIBM
-	if (_LIB_VERSION == _SVID_)
-	  {
-	    y = __ieee754_lgamma_r(x,&signgam);
-
-	    if(!__finite(y)&&__finite(x)) {
-	      if(__floor(x)==x&&x<=(double)0.0)
-		/* lgamma pole */
-		return __kernel_standard(x,x,15);
-	      else
-		/* lgamma overflow */
-		return __kernel_standard(x,x,14);
-	    }
-	  }
-	else
-	  {
-#endif
-	    int local_signgam;
-	    y = __ieee754_gamma_r(x,&local_signgam);
-	    if (local_signgam < 0) y = -y;
+	int local_signgam;
+	y = __ieee754_gamma_r(x,&local_signgam);
+	if (local_signgam < 0) y = -y;
 #ifdef _IEEE_LIBM
-	    return y;
+	return y;
 #else
-	    if(_LIB_VERSION == _IEEE_) return y;
+	if(_LIB_VERSION == _IEEE_) return y;
 
-	    if(!__finite(y)&&__finite(x)) {
-	      if(__floor(x)==x&&x<=0.0)
-                return __kernel_standard(x,x,41); /* gamma pole */
-	      else
-                return __kernel_standard(x,x,40); /* gamma overflow */
-	    }
-	  }
+	if(!__finite(y)&&__finite(x)) {
+	  if(__floor(x)==x&&x<=0.0)
+	    return __kernel_standard(x,x,41); /* tgamma pole */
+	  else
+	    return __kernel_standard(x,x,40); /* tgamma overflow */
+	}
 	return y;
 #endif
 }
-weak_alias (__gamma, gamma)
+weak_alias (__tgamma, tgamma)
 #ifdef NO_LONG_DOUBLE
-strong_alias (__gamma, __gammal)
-weak_alias (__gamma, gammal)
+strong_alias (__tgamma, __tgammal)
+weak_alias (__tgamma, tgammal)
 #endif